Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(434)

Unified Diff: ios/chrome/browser/ui/content_suggestions/content_suggestions_favicon_item.h

Issue 2644123003: Move ios/ui/suggestions to ios/ui/content_suggestions (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/ui/content_suggestions/content_suggestions_favicon_item.h
diff --git a/ios/chrome/browser/ui/suggestions/suggestions_favicon_item.h b/ios/chrome/browser/ui/content_suggestions/content_suggestions_favicon_item.h
similarity index 59%
rename from ios/chrome/browser/ui/suggestions/suggestions_favicon_item.h
rename to ios/chrome/browser/ui/content_suggestions/content_suggestions_favicon_item.h
index 235944e9979ac1cec77e3346ad437664ea155ea5..9e61d5ffa94201deea73209c5dc231ff2785351f 100644
--- a/ios/chrome/browser/ui/suggestions/suggestions_favicon_item.h
+++ b/ios/chrome/browser/ui/content_suggestions/content_suggestions_favicon_item.h
@@ -2,15 +2,15 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_FAVICON_ITEM_H_
-#define IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_FAVICON_ITEM_H_
+#ifndef IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_FAVICON_ITEM_H_
+#define IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_FAVICON_ITEM_H_
#import "ios/chrome/browser/ui/collection_view/cells/collection_view_item.h"
#import "ios/third_party/material_components_ios/src/components/CollectionCells/src/MaterialCollectionCells.h"
-// Delegate for the SuggestionsFaviconCell, handling the interaction with the
-// inner collection view.
-@protocol SuggestionsFaviconCellDelegate
+// Delegate for the ContentSuggestionsFaviconCell, handling the interaction with
+// the inner collection view.
+@protocol ContentSuggestionsFaviconCellDelegate
// Opens the favicon associated with the |indexPath| of the internal cell.
- (void)openFaviconAtIndexPath:(NSIndexPath*)innerIndexPath;
@@ -20,9 +20,9 @@
// Item for a cell containing favicons in the suggestions. The favicons are
// presented in an inner collection view contained in the cell associated with
// this item. The collection view scrolls horizontally.
-@interface SuggestionsFaviconItem : CollectionViewItem
+@interface ContentSuggestionsFaviconItem : CollectionViewItem
-@property(nonatomic, weak) id<SuggestionsFaviconCellDelegate> delegate;
+@property(nonatomic, weak) id<ContentSuggestionsFaviconCellDelegate> delegate;
// Adds a favicon with a |favicon| image and a |title| to this item.
- (void)addFavicon:(UIImage*)favicon withTitle:(NSString*)title;
@@ -30,13 +30,13 @@
@end
// The corresponding cell of a favicon item.
-@interface SuggestionsFaviconCell : MDCCollectionViewCell
+@interface ContentSuggestionsFaviconCell : MDCCollectionViewCell
// The inner collection view, used to display the favicons.
@property(nonatomic, strong) UICollectionView* collectionView;
-@property(nonatomic, weak) id<SuggestionsFaviconCellDelegate> delegate;
+@property(nonatomic, weak) id<ContentSuggestionsFaviconCellDelegate> delegate;
@end
-#endif // IOS_CHROME_BROWSER_UI_SUGGESTIONS_SUGGESTIONS_FAVICON_ITEM_H_
+#endif // IOS_CHROME_BROWSER_UI_CONTENT_SUGGESTIONS_CONTENT_SUGGESTIONS_FAVICON_ITEM_H_

Powered by Google App Engine
This is Rietveld 408576698